/**
 * DCOPApp
 */
package leds;

/**
 * Interface between an instance of a DCOP-enabled application and the code
 * 
 * @author costing
 * @since Dec 30, 2008
 */
public class DCOPApp implements KDEApp {
	/**
	 * DCOP session
	 */
	private final DCOPSession dcopSession;
	
	/**
	 * Application name
	 */
	private final String sApplication;
	
	/**
	 * Package protected constructor (built by {@link DCOPSession#getApplications()} 
	 * 
	 * @param session DCOP session
	 * @param application application name
	 * @see Utils#getDCOPApp(String)
	 */
	DCOPApp(final DCOPSession session, final String application){
		this.dcopSession = session; 
		this.sApplication = application;
	}
	
	/**
	 * Call a function on this application
	 * 
	 * @param module application module
	 * @param function function name
	 * @param args arguments
	 * @return output
	 */
	public String execute(final String module, final String function, final String... args){
		final String sDCOP = Utils.getDCOPPath();
		
		if (sDCOP==null)
			return null;
		
		final String[] commandLine = new String[9 + args.length];
		
		commandLine[0] = sDCOP;
		commandLine[1] = "--no-user-time"; //$NON-NLS-1$
		commandLine[2] = "--user"; //$NON-NLS-1$
		commandLine[3] = this.dcopSession.getAccount();
		commandLine[4] = "--session"; //$NON-NLS-1$
		commandLine[5] = this.dcopSession.getSession();
		commandLine[6] = this.sApplication;
		commandLine[7] = module;
		commandLine[8] = function;
		
		for (int i=0; i<args.length; i++)
			commandLine[9 + i] = args[i];
		
		return Utils.getProgramOutput(commandLine);
	}
	
	/**
	 * Get application name
	 * 
	 * @return application name
	 */
	public String getApplication(){
		return this.sApplication;
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return this.sApplication+"@"+this.dcopSession.toString();  //$NON-NLS-1$
	}
}
