package leds;

/**
 * Values (String -> Double) mapping, used extensively by {@link Utils} to return many values at once. 
 * 
 * @author costing
 * @since Oct 7, 2008
 */
public class Values extends java.util.LinkedHashMap<String, Double> {
	/**
	 * Stop complaining about the serial :)
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Subtract the same values from the other array, making sure the values don't get negative, after
	 * all we are monitoring counters.
	 * 
	 * @param old previous values of the counters
	 * @return set of differences between current and old values
	 */
	public Values substract(final Values old) {
		final Values ret = new Values();

		for (java.util.Map.Entry<String, Double> me : entrySet()) {
			double dOld = old.getz(me.getKey());

			ret.put(me.getKey(), Double.valueOf(me.getValue().doubleValue() >= dOld ? me.getValue().doubleValue() - dOld : 0));
		}

		return ret;
	}

	/**
	 * Divide all the values with the same number (to obtain rates).
	 * 
	 * @param d number to divide all values by
	 * @return the divided values
	 */
	public Values div(final double d) {
		final Values ret = new Values();

		for (java.util.Map.Entry<String, Double> me : entrySet()) {
			ret.put(me.getKey(), Double.valueOf(me.getValue().doubleValue() / d));
		}

		return ret;
	}

	/**
	 * Get the value as integer.
	 * 
	 * @param sKey key
	 * @return integer-rounded value
	 */
	public int getInt(final String sKey) {
		return (int) Math.round(get(sKey).doubleValue());
	}

	/**
	 * Get the value as double, returning zero if the value is missing from the current set.
	 * 
	 * @param sKey key
	 * @return double value
	 */
	public double getz(final String sKey) {
		final Double d = get(sKey);

		return d != null ? d.doubleValue() : 0;
	}

}
