/**
 * 
 */
package leds.modules;

import java.awt.Graphics2D;

import leds.Canvas;
import leds.ExtProperties;
import leds.Utils;

/**
 * Display the battery charge by looking in /proc/acpi/battery/BAT0/{info,state}
 * 
 * @author costing
 * @since Oct 20, 2008
 * @see Utils#getBattery()
 */
public class Battery extends BaseModule {

	/**
	 * Height of the battery area, in pixels
	 */
	private int BATT_H = 26;
	/**
	 * Width of the battery area, in pixels
	 */
	private int BATT_W = 6;
	
	/* (non-Javadoc)
	 * @see leds.modules.BaseModule#init(leds.ExtProperties, int, int)
	 */
	@Override
	public void init(final ExtProperties config, final int xstart, final int ystart) {
		super.init(config, xstart, ystart);
		
		this.BATT_H = config.geti("leds.modules.Battery.height", 32) - 6; //$NON-NLS-1$
		this.BATT_W = config.geti("leds.modules.Battery.width", 10) - 4; //$NON-NLS-1$
	}
	
	/* (non-Javadoc)
	 * @see leds.Module#draw(leds.Canvas)
	 */
	@Override
	public boolean draw(final Canvas c) {
		final Graphics2D graphics = c.getGraphics();

		if (this.height==0)
			this.height=this.BATT_H+6;
		
		if (this.width==0)
			this.width=this.BATT_W+4;
		
		// battery outer shape
		graphics.drawRect(this.x, this.y + 2, this.BATT_W + 3, this.BATT_H + 3);
		graphics.drawRect(this.x + 3, this.y, this.BATT_W - 3, 2);

		try {
			final double percentage = Utils.getBattery().getz("percentage"); //$NON-NLS-1$

			if (percentage >= 0) {
				final int pixels = (int) (this.BATT_H * this.BATT_W * percentage);

				final int h = pixels / this.BATT_W;

				final int remaining = pixels - h * this.BATT_W;

				graphics.fillRect(this.x + 2, this.y + 4 + (this.BATT_H - h), this.BATT_W, h);

				if (remaining > 0)
					graphics.fillRect(this.x + 2, this.y + 4 + (this.BATT_H - h - 1), remaining, 1);

				if (percentage < 0.1) {
					graphics.fillRect(this.x + 4, this.y + 5 + this.BATT_H / 6, this.BATT_W / 2, this.BATT_H / 4);
					graphics.fillRect(this.x + 4, this.y + 5 + this.BATT_H / 2, this.BATT_W / 2, this.BATT_H / 10);
				}
			}
		}
		catch (Exception e) {
			// ignore
		}
		
		return true;
	}
	
}
