/**
 * 
 */
package leds.modules;

import java.awt.Graphics2D;

import leds.Canvas;
import leds.Utils;

/**
 * Display the CPU temperature as reported by the ACPI sensor, either /sys/class/thermal/thermal_zone0/temp or 
 * /proc/acpi/thermal_zone/THRM/temperature.
 * 
 * @author costing
 * @since Oct 20, 2008
 * @see Utils#getCPUTemperature()
 */
public class CPUTemperature extends BaseModule {

	/**
	 * Error determining the temperature. Don't try to run after it.
	 */
	private boolean bError = false;
	
	/* (non-Javadoc)
	 * @see leds.Module#draw(leds.Canvas)
	 */
	@Override
	public boolean draw(final Canvas c) {
		if (this.bError)
			return false;
		
		final int temperature = Utils.getCPUTemperature();
		
		if (temperature == Utils.CPU_TEMP_ERROR){
			this.bError = true;
			return false;
		}
		
		final Graphics2D graphics = c.getGraphics();
		
		if (this.width==0)
			this.width = c.getTextWidth("99") + 13; //$NON-NLS-1$
		
		if (this.height==0)
			this.height = c.getTextHeight() - 2;
		
		final int where = this.x + this.width;

		final int Y3 = this.y + this.height;
		
		c.drawString(""+temperature, where-13, Y3, Canvas.ALIGN_RIGHT); //$NON-NLS-1$
	
		graphics.drawRect(where - 10, Y3-c.getTextHeight()+2, 2, 2);
		
		c.drawString("C", where, Y3, Canvas.ALIGN_RIGHT); //$NON-NLS-1$
		
		return true;
	}

}
