/**
 * 
 */
package leds.modules;

import leds.Canvas;
import leds.Utils;
import leds.Values;

/**
 * Display the CPU utilization, in percentage, since the last drawing.
 * 
 * @author costing
 * @since Oct 20, 2008
 * @see Utils#getCPU()
 */
public class CPUUsage extends BaseModule {	
	/**
	 * String we display on top
	 */
	private static final String header = "usr sys iow idl"; //$NON-NLS-1$
	
	/**
	 * Initialize the counters
	 */
	public CPUUsage(){
		Utils.getCPU();
	}
	
	/* (non-Javadoc)
	 * @see leds.Module#draw(leds.Canvas)
	 */
	@Override
	public boolean draw(final Canvas c) {
		if (this.height==0)
			this.height = c.getTextHeight() - 2;
	
		if (this.width==0)
			this.width = c.getTextWidth(header);
		
		final Values cpu = Utils.getCPU();

		final int cpu_usr = (int) Math.round(100.0d * (cpu.getz("usr") + cpu.getz("nice"))); //$NON-NLS-1$ //$NON-NLS-2$
		final int cpu_sys = (int) Math.round(100.0d * (cpu.getz("sys") + cpu.getz("int") + cpu.getz("softint") + cpu.getz("steal"))); //$NON-NLS-1$//$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
		final int cpu_iow = (int) Math.round(100.0d * (cpu.getz("iowait"))); //$NON-NLS-1$
		final int cpu_idle = Math.max(100 - cpu_usr - cpu_sys - cpu_iow, 0);
		
		c.drawString(header, this.x, this.y+this.height);

		c.drawString(Integer.valueOf(cpu_usr), this.x+21, this.y+2*this.height+2, Canvas.ALIGN_RIGHT);
		c.drawString(Integer.valueOf(cpu_sys), this.x+50, this.y+2*this.height+2, Canvas.ALIGN_RIGHT);
		c.drawString(Integer.valueOf(cpu_iow), this.x+78, this.y+2*this.height+2, Canvas.ALIGN_RIGHT);
		c.drawString(Integer.valueOf(cpu_idle), this.x+105, this.y+2*this.height+2, Canvas.ALIGN_RIGHT);
		
		return true;
	}
}
