/**
 * 
 */
package leds.modules;

import java.awt.Font;
import java.text.SimpleDateFormat;
import java.util.Date;

import leds.Canvas;
import leds.ExtProperties;

/**
 * Display the date and time.
 * 
 * @author costing
 * @since Oct 20, 2008
 */
public class DateTime extends BaseModule {

	/**
	 * Date formatting class
	 */
	private SimpleDateFormat sdf = null;
	
	/**
	 * Timezone offset
	 */
	private long lTimeOffset = 0;
	
	/**
	 * The font used to print the date and time on the display
	 */
	private static final Font font = new Font("Courier New", Font.BOLD, 11);  //$NON-NLS-1$
	
	@Override
	public void init(final ExtProperties config, final int xStart, final int yStart) {
		super.init(config, xStart, yStart);
		
		this.sdf = new SimpleDateFormat(config.gets("leds.modules.DateTime.format", "HH:mm dd.MM.yyyy")); //$NON-NLS-1$ //$NON-NLS-2$
	
		this.lTimeOffset = config.geti("leds.modules.DateTime.offset", 0)*60L*60*1000; //$NON-NLS-1$
	}
	
	/* (non-Javadoc)
	 * @see leds.Module#draw(leds.Canvas)
	 */
	@Override
	public boolean draw(final Canvas c) {
		final Font fOld = c.getGraphics().getFont();
		
		c.getGraphics().setFont(font);
		
		if (this.height==0)
			this.height = c.getTextHeight() - 2;
		
		if (this.width==0)
			this.width = c.getTextWidth(this.sdf.toPattern());
		
		c.drawString(this.sdf.format(new Date(System.currentTimeMillis() + this.lTimeOffset)), this.x, this.y + this.height);
		
		c.getGraphics().setFont(fOld);
		
		return true;
	}

}
