/**
 * 
 */
package leds.modules;

import java.awt.Graphics2D;

import leds.Canvas;
import leds.ExtProperties;
import leds.Utils;
import leds.Values;

/**
 * Display the temperature of the internal hard disk, as reported by smartctl.
 * 
 * @author costing
 * @since Oct 20, 2008
 * @see Utils#getHDDParameters(String)
 */
public class HDDTemperature extends BaseModule {

	/**
	 * Device name (/dev/sda for example)
	 */
	String sDevice;
	
	/**
	 * Temperature to display. We don't query hdd temperature too often ...
	 */
	int iTemperature;
	
	/**
	 * When did we check the temperature last ?
	 */
	long lLastChecked = 0;
	
	/**
	 * How often to check the temperature?
	 */
	long lCheckInterval = 30000;
	
	/**
	 * What key to take from smartctl's output
	 */
	private static final String sKey = "Temperature_Celsius"; //$NON-NLS-1$
	
	/* (non-Javadoc)
	 * @see leds.modules.BaseModule#init(leds.ExtProperties, int, int)
	 */
	@Override
	public void init(final ExtProperties config, final int xstart, final int ystart) {
		super.init(config, xstart, ystart);
		
		this.sDevice = config.gets("leds.modules.HDDTemperature.device", "/dev/sda"); //$NON-NLS-1$ //$NON-NLS-2$
	
		this.lCheckInterval = config.getl("leds.modules.HDDTemperature.check_interval", 30000); //$NON-NLS-1$
		
		getTemp();
		
		if (this.iTemperature<0){
			System.err.println("Sorry, cannot get the temperature for "+this.sDevice+". Did you install smartctl? Are you running the app as root?");  //$NON-NLS-1$//$NON-NLS-2$
		}
	}
	
	/**
	 * Update the temperature
	 */
	private void getTemp(){
		if (System.currentTimeMillis() - this.lLastChecked > this.lCheckInterval){
			this.lLastChecked = System.currentTimeMillis();
			
			final Values v = Utils.getHDDParameters(this.sDevice);
			
			try{
				this.iTemperature = v.getInt(sKey);
			}
			catch (Exception e){
				this.iTemperature = -1;
			}
		}
	}
	
	/* (non-Javadoc)
	 * @see leds.Module#draw(leds.Canvas)
	 */
	@Override
	public boolean draw(Canvas c) {
		if (this.iTemperature < 0)
			return false;
		
		getTemp();
		
		final Graphics2D graphics = c.getGraphics();
		
		if (this.width==0)
			this.width = c.getTextWidth("99") + 13; //$NON-NLS-1$
		
		if (this.height==0)
			this.height = c.getTextHeight() - 2;
		
		final int where = this.x + this.width;

		final int Y3 = this.y + this.height;
		
		c.drawString(""+this.iTemperature, where-13, Y3, Canvas.ALIGN_RIGHT); //$NON-NLS-1$
	
		graphics.drawRect(where - 10, Y3-c.getTextHeight()+2, 2, 2);
		
		c.drawString("C", where, Y3, Canvas.ALIGN_RIGHT); //$NON-NLS-1$
		
		return true;
	}

}
